@@ -1,4 +1,6 @@
 from graphio.objects.nodeset import NodeSet
+from graphio.objects.unstructured_nodeset import UnstructuredNodeSet
+from graphio.objects.unstructured_relationshipset import UnstructuredRelationshipSet
 from graphio.objects.relationshipset import RelationshipSet
 from graphio.objects.datacontainer import Container
 from graphio.model import ModelNode, ModelRelationship, MergeKey, Label, NodeDescriptor
