@@ -7,7 +7,11 @@ def test_create_single_index(graph, clear_graph):
 
     create_single_index(graph, test_label, test_prop)
 
-    result = run_query_return_results(graph, "CALL db.indexes()")
+    # TODO keep until 4.2 is not supported anymore
+    try:
+        result = run_query_return_results(graph, "SHOW INDEXES YIELD *")
+    except:
+        result = run_query_return_results(graph, "CALL db.indexes()")
     row = result[0]
 
     # the result of the db.indexes() procedure is different for Neo4j 3.5 and 4
@@ -27,7 +31,11 @@ def test_create_composite_index(graph, clear_graph):
 
     create_composite_index(graph, test_label, test_properties)
 
-    result = run_query_return_results(graph, "CALL db.indexes()")
+    # TODO keep until 4.2 is not supported anymore
+    try:
+        result = run_query_return_results(graph, "SHOW INDEXES YIELD *")
+    except:
+        result = run_query_return_results(graph, "CALL db.indexes()")
 
     row = result[0]
 
